@@ -99,7 +99,7 @@ class ImageRecognition(object):
                                 use_bias=False)
             
             if self.classification_by_regression: 
-                out = 6 /(1 + tf.exp(-0.2 * out)) - 3
+                out = 1.0 /(1.0 + tf.exp(-0.2 * out)) 
                 #out[:, 1] = 1.0 - out[:, 0]
 
             else: 
@@ -185,7 +185,7 @@ class ImageRecognition(object):
 
             
             if self.classification_by_regression:
-                out = 6 /(1 + tf.exp(-0.2 * out)) - 3
+                out = 1.0 /(1 + tf.exp(-0.2 * out)) 
                 #out[:, 1] = 1.0 - out[:, 0]
             
             else: 
@@ -254,7 +254,7 @@ class ImageRecognition(object):
                                     use_bias=False)
 
             if self.classification_by_regression:
-                out = 6 /(1 + tf.exp(-0.2 * out)) - 3
+                out = 1.0 /(1 + tf.exp(-0.2 * out)) 
                 #out[:, 1] = 1.0 - out[:, 0]
 
             else: 
